-- basic grid map class

-- requires something like this
-- map = { data = {}, info = {w = tilewidth, h = tileheight, tileindex = { { i = imagesheetreference, q = quadreference }, } } }
-- data can be created like this
-- map = require "ow_grid"
-- map:create(10,10,{ list of tilepositions and their values like this {xpos, ypos, position of draw information in map.info.tileindex } })
-- then the map is ready to draw simply like this
-- map:draw()

local grid = {}

-- draw function
function grid:draw(x,y)
	for i = 1,#self.data do
		for j = 1,#self.data[i] do
			if self.data[i][j][1] > 0 then
				local rotation = self.data[i][j].r or 0
				rotation = math.rad(rotation)
				love.graphics.drawq( 
					self.info.tileindex[self.data[i][j][1]][1],
					self.info.tileindex[self.data[i][j][1]][2],
					x+(self.info.w*(j-1))+(self.info.w*0.5), 
					y+(self.info.h*(i-1))+(self.info.h*0.5),
					rotation,
					1,
					1,
					self.info.w*0.5,
					self.info.h*0.5
				)
				rotation = nil
			end
		end
	end
end

-- create the tile data for drawing the map from a string on non blank tiles and their positions
function grid:create(width,height,tilepos)
	self.data = {}
	for i = 1,height do
		self.data[i] = {}
		for j = 1,width do
			self.data[i][j] = {0}
		end
	end
	for i = 1,#tilepos do
		assert(tilepos[i][1] <= width, "tilepos ".. i .." is too far on the x plane for the width of the map.")
		assert(tilepos[i][2] <= height, "tilepos ".. i .." is too far on the y plane for the height of the map.")
		self.data[tilepos[i][2]][tilepos[i][1]] = tilepos[i][3]
	end
end

-- create the references for the quads of tiles
function grid:setup(imagesheet,tilenumber,tilewidth,tileheight)
	-- setup the basics before running up the quads and tilewidths
	self.info = {}
	self.info.w = tilewidth
	self.info.h = tileheight
	self.info.is = love.graphics.newImage(imagesheet)
	
	-- calculate how many in a row and how many rows the tiles require
	local numberinrow,_ = math.modf(self.info.is:getWidth() / tilewidth)
	_ = nil
	local numberrows,_ = math.modf(self.info.is:getHeight() / tileheight)
	_ = nil
	
	self.info.tileindex = {}
	for i = 1,tilenumber do
		local y,_ = math.modf(i/numberinrow)
		_ = nil
		local x = i - (y*numberinrow)
		
		x = ((x-1)*tilewidth)
		y = y * tileheight
		
		self.info.tileindex[i] = {self.info.is,love.graphics.newQuad( x, y, tilewidth, tileheight, self.info.is:getWidth(), self.info.is:getHeight() ),}
		x,y = nil,nil
	end
	
	numberinrow,numberrows = nil,nil
end
	
return grid