local newgame = {}

newgame.font = love.graphics.newFont("fonts/Lekton-Bold.ttf",36)
newgame.fontsmall = love.graphics.newFont("fonts/Lekton-Bold.ttf",20)
newgame.mouse = {
		{
			x=(love.graphics.getWidth()*0.15),
			y=(love.graphics.getHeight()*0.347)+10,
			w=24,
			h=24,
			action={"opponents","-"},
		},
		{
			x=(love.graphics.getWidth()*0.35),
			y=(love.graphics.getHeight()*0.347)+10,
			w=24,
			h=24,
			action={"opponents","+"},
		},
		{
			x=(love.graphics.getWidth()*0.4),
			y=(love.graphics.getHeight()*0.347)+10,
			w=24,
			h=24,
			action={"opponents","*"},
		},
		--
		{
			x=(love.graphics.getWidth()*0.15),
			y=(love.graphics.getHeight()*0.447)+10,
			w=24,
			h=24,
			action={"fertility","-"},
		},
		{
			x=(love.graphics.getWidth()*0.35),
			y=(love.graphics.getHeight()*0.447)+10,
			w=24,
			h=24,
			action={"fertility","+"},
		},
		{
			x=(love.graphics.getWidth()*0.4),
			y=(love.graphics.getHeight()*0.447)+10,
			w=24,
			h=24,
			action={"fertility","*"},
		},
		--
		{
			x=(love.graphics.getWidth()*0.15),
			y=(love.graphics.getHeight()*0.547)+10,
			w=24,
			h=24,
			action={"size","-"},
		},
		{
			x=(love.graphics.getWidth()*0.35),
			y=(love.graphics.getHeight()*0.547)+10,
			w=24,
			h=24,
			action={"size","+"},
		},
		--
		{
			x=love.graphics.getWidth()*0.25,
			y=(love.graphics.getHeight()*0.75)+18,
			w=newgame.font:getWidth("Return"),
			h=34,
			action={"return"},
		},
		--
		{
			x=love.graphics.getWidth()*0.75,
			y=(love.graphics.getHeight()*0.75)+18,
			w=newgame.font:getWidth("Play"),
			h=34,
			action={"play"},
		},
	}

newgame.positionmap = function(target)
	target = target or "both"

	-- create data
	local data = {}
	data.plants,_ = math.modf(((game.settings.mapsize*3)*(game.settings.mapsize*3))*(game.settings.fertility*0.01))
	_ = nil
	
	local positions = {}
	
	if newgame.positions == nil or #newgame.positions ~= game.settings.mapsize*3 or target == "both" then
		-- populate table
		for i = 1,game.settings.mapsize*3 do
			table.insert(positions,{})
			for j = 1,game.settings.mapsize*3 do
				table.insert(positions[i],"empty")
			end
		end
	else
		if target == "plants" then
			positions = newgame.positions
			for i = 1,game.settings.mapsize*3 do
				for j = 1,game.settings.mapsize*3 do
					if positions[i][j] == "plant" then
						positions[i][j] = "empty"
					end
				end
			end
		elseif target == "players" then
			positions = newgame.positions
			for i = 1,game.settings.mapsize*3 do
				for j = 1,game.settings.mapsize*3 do
					if type(positions[i][j]) == "number" then
						positions[i][j] = "empty"
					end
				end
			end
		end
	end
	
	if target == "both" or target == "plants" then
		-- place plants
		repeat
			local x,y = math.random(1,game.settings.mapsize*3),math.random(1,game.settings.mapsize*3)
			if positions[y][x] == "empty" then
				positions[y][x] = "plant"
				data.plants = data.plants - 1
			end
			x,y = nil,nil
		until data.plants == 0
	
		data = nil
	end
	
	if target == "both" or target == "players" then
		for i = 0,game.settings.opponents do
			repeat
				local test = false
				local x,y = math.random(1,game.settings.mapsize*3),math.random(1,game.settings.mapsize*3)
				if positions[y][x] == "empty" then
					positions[y][x] = i
					test = true
				end
				x,y = nil,nil
			until test == true
		end
	end
	
	return positions
end

-- populate map
newgame.positions = newgame.positionmap()

newgame.draw = function()
	love.graphics.setFont(newgame.fontsmall)
	love.graphics.setColor(150,0,0,game.states:getAlpha("newgame"))
	
	-- blocks for the settings
	
	-- opponents
	love.graphics.print("Opponents",(love.graphics.getWidth()*0.25)-(newgame.fontsmall:getWidth("Opponents")*0.5),love.graphics.getHeight()*0.3)
	if game.settings.opponents == 0 then
		love.graphics.print("None",(love.graphics.getWidth()*0.25)-(newgame.fontsmall:getWidth("None")*0.5),love.graphics.getHeight()*0.35)
	elseif game.settings.opponents == 1 then
		love.graphics.setColor(0,0,200,game.states:getAlpha("newgame"))
		love.graphics.circle( "fill", love.graphics.getWidth()*0.25, love.graphics.getHeight()*0.36, 10, 10 )
	elseif game.settings.opponents == 2 then
		love.graphics.setColor(0,0,200,game.states:getAlpha("newgame"))
		love.graphics.circle( "fill", love.graphics.getWidth()*0.22, love.graphics.getHeight()*0.36, 10, 10 )
		love.graphics.setColor(200,200,0,game.states:getAlpha("newgame"))
		love.graphics.circle( "fill", love.graphics.getWidth()*0.28, love.graphics.getHeight()*0.36, 10, 10 )
	end
	love.graphics.setColor(150,0,0,game.states:getAlpha("newgame"))
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.15)-10,love.graphics.getHeight()*0.347,20,20)
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.35)-10,love.graphics.getHeight()*0.347,20,20)
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.40)-10,love.graphics.getHeight()*0.347,20,20)
	
	love.graphics.setColor(game.settings.seacolor[1],game.settings.seacolor[2],game.settings.seacolor[3],game.states:getAlpha("newgame"))
	love.graphics.print("-",(love.graphics.getWidth()*0.15)-(newgame.fontsmall:getWidth("+")*0.5),love.graphics.getHeight()*0.347)
	love.graphics.print("+",(love.graphics.getWidth()*0.35)-(newgame.fontsmall:getWidth("+")*0.5),love.graphics.getHeight()*0.347)
	love.graphics.print("*",(love.graphics.getWidth()*0.4)-(newgame.fontsmall:getWidth("*")*0.5),love.graphics.getHeight()*0.347)
	
	-- fertility
	love.graphics.setColor(150,0,0,game.states:getAlpha("newgame"))
	love.graphics.print("Land Fertility",(love.graphics.getWidth()*0.25)-(newgame.fontsmall:getWidth("Land Fertility")*0.5),love.graphics.getHeight()*0.4)
	love.graphics.print(game.settings.fertility.."%",(love.graphics.getWidth()*0.25)-(newgame.fontsmall:getWidth(game.settings.fertility.."%")*0.5),love.graphics.getHeight()*0.45)
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.15)-10,love.graphics.getHeight()*0.447,20,20)
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.35)-10,love.graphics.getHeight()*0.447,20,20)
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.40)-10,love.graphics.getHeight()*0.447,20,20)
	love.graphics.setColor(game.settings.seacolor[1],game.settings.seacolor[2],game.settings.seacolor[3],game.states:getAlpha("newgame"))
	love.graphics.print("-",(love.graphics.getWidth()*0.15)-(newgame.fontsmall:getWidth("+")*0.5),love.graphics.getHeight()*0.447)
	love.graphics.print("+",(love.graphics.getWidth()*0.35)-(newgame.fontsmall:getWidth("+")*0.5),love.graphics.getHeight()*0.447)
	love.graphics.print("*",(love.graphics.getWidth()*0.4)-(newgame.fontsmall:getWidth("*")*0.5),love.graphics.getHeight()*0.447)
	
	-- map size
	love.graphics.setColor(150,0,0,game.states:getAlpha("newgame"))
	love.graphics.print("Map Size",(love.graphics.getWidth()*0.25)-(newgame.fontsmall:getWidth("Map Size")*0.5),love.graphics.getHeight()*0.5)
	love.graphics.print(game.settings.mapsize*game.settings.mapsize,(love.graphics.getWidth()*0.25)-(newgame.fontsmall:getWidth(game.settings.mapsize*game.settings.mapsize)*0.5),love.graphics.getHeight()*0.55)
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.15)-10,love.graphics.getHeight()*0.547,20,20)
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.35)-10,love.graphics.getHeight()*0.547,20,20)
	love.graphics.setColor(game.settings.seacolor[1],game.settings.seacolor[2],game.settings.seacolor[3],game.states:getAlpha("newgame"))
	love.graphics.print("-",(love.graphics.getWidth()*0.15)-(newgame.fontsmall:getWidth("+")*0.5),love.graphics.getHeight()*0.547)
	love.graphics.print("+",(love.graphics.getWidth()*0.35)-(newgame.fontsmall:getWidth("+")*0.5),love.graphics.getHeight()*0.547)
	
	-- blocks for the preview map
	
	-- map title
	love.graphics.setColor(150,0,0,game.states:getAlpha("newgame"))
	love.graphics.print("Map:",(love.graphics.getWidth()*0.53)-(newgame.fontsmall:getWidth("Map:")*0.5),love.graphics.getHeight()*0.3)
	
	-- map box fill
	love.graphics.setColor(0,0,0,game.states:getAlpha("newgame")*0.25)
	love.graphics.rectangle("fill",(love.graphics.getWidth()*0.58),love.graphics.getHeight()*0.3,250,187.5)
	
	-- map box plants and players
	for i = 0,#newgame.positions-1 do
		for j = 0,#newgame.positions[i+1]-1 do
			-- plant
			if newgame.positions[i+1][j+1] == "plant" then
				love.graphics.setColor(0,150,0,game.states:getAlpha("newgame"))
				love.graphics.rectangle("fill",((love.graphics.getWidth()*0.58)+(i*(250/(game.settings.mapsize*3))))+2,((love.graphics.getHeight()*0.3)+(j*(187.5/(game.settings.mapsize*3))))+2,(250/(game.settings.mapsize*3))-4,(187.5/(game.settings.mapsize*3))-4)
			-- empty boxes
			elseif newgame.positions[i+1][j+1] == "empty" then
				love.graphics.setColor(0,0,0,game.states:getAlpha("newgame")*0.25)
				love.graphics.rectangle("fill",((love.graphics.getWidth()*0.58)+(i*(250/(game.settings.mapsize*3))))+2,((love.graphics.getHeight()*0.3)+(j*(187.5/(game.settings.mapsize*3))))+2,(250/(game.settings.mapsize*3))-4,(187.5/(game.settings.mapsize*3))-4)
			-- player and opponents
			elseif type(newgame.positions[i+1][j+1]) == "number" then
				if newgame.positions[i+1][j+1] == 0 then
					love.graphics.setColor(200,0,0,game.states:getAlpha("newgame"))
					love.graphics.rectangle("fill",((love.graphics.getWidth()*0.58)+(i*(250/(game.settings.mapsize*3))))+2,((love.graphics.getHeight()*0.3)+(j*(187.5/(game.settings.mapsize*3))))+2,(250/(game.settings.mapsize*3))-4,(187.5/(game.settings.mapsize*3))-4)
				elseif newgame.positions[i+1][j+1] == 1 then
					love.graphics.setColor(0,0,200,game.states:getAlpha("newgame"))
					love.graphics.rectangle("fill",((love.graphics.getWidth()*0.58)+(i*(250/(game.settings.mapsize*3))))+2,((love.graphics.getHeight()*0.3)+(j*(187.5/(game.settings.mapsize*3))))+2,(250/(game.settings.mapsize*3))-4,(187.5/(game.settings.mapsize*3))-4)
				elseif newgame.positions[i+1][j+1] == 2 then
					love.graphics.setColor(200,200,0,game.states:getAlpha("newgame"))
					love.graphics.rectangle("fill",((love.graphics.getWidth()*0.58)+(i*(250/(game.settings.mapsize*3))))+2,((love.graphics.getHeight()*0.3)+(j*(187.5/(game.settings.mapsize*3))))+2,(250/(game.settings.mapsize*3))-4,(187.5/(game.settings.mapsize*3))-4)
				end
			end
		end
	end
	
	
	
	-- map box outline
	love.graphics.setColor(150,0,0,game.states:getAlpha("newgame"))
	love.graphics.rectangle("line",(love.graphics.getWidth()*0.58),love.graphics.getHeight()*0.3,250,187.5)
	
	-- final return or play block
	love.graphics.setFont(newgame.font)
	love.graphics.print("Return",(love.graphics.getWidth()*0.25)-(newgame.font:getWidth("Return")*0.5),love.graphics.getHeight()*0.75)
	love.graphics.print("Play",(love.graphics.getWidth()*0.75)-(newgame.font:getWidth("Play")*0.5),love.graphics.getHeight()*0.75)

end

newgame.update = function(dt)
	if newgame.destination then
		if game.states:getAlpha("newgame") == 0 then
			game.states:purge("newgame")
			if newgame.destination == "return" then
				game.states:add("menu","code/states/menu.lua",1)
			elseif newgame.destination == "play" then
				game.states:add("gamecore","code/states/gamecore.lua",1)
				game.states:add("gameui","code/states/gameui.lua",1)
			end
		end
	end
end

function newgame.mouseActions(x,y,button)
	-- declare table at top of file
	
	-- test
	local action = ow.mouse.detectAction(x,y,newgame.mouse)
	--NULL INPUT
	--stops it from crashing if theres nothing at click
	if action ~= nil then
		
		-- begin various tests by assessing the 
		
		-- options
		if action[2][1] == "opponents" then
			if action[2][2] == "-" then
				if game.settings.opponents >= 1 then
					game.settings.opponents = game.settings.opponents - 1
					newgame.positions = newgame.positionmap("players")
				end
			elseif action[2][2] == "+" then
				if game.settings.mapsize > 1 and game.settings.opponents < 1 then
					game.settings.opponents = game.settings.opponents + 1
					newgame.positions = newgame.positionmap("players")
				elseif game.settings.mapsize > 2 and game.settings.opponents <= 1 then
					game.settings.opponents = game.settings.opponents + 1
					newgame.positions = newgame.positionmap("players")
				end
			elseif action[2][2] == "*" then
				newgame.positions = newgame.positionmap("players")
			end
		elseif action[2][1] == "fertility" then
			if action[2][2] == "-" then
				if game.settings.fertility >= 20 then
					game.settings.fertility = game.settings.fertility - 10
					newgame.positions = newgame.positionmap("plants")
				end
			elseif action[2][2] == "+" then
				if game.settings.fertility <= 70 then
					game.settings.fertility = game.settings.fertility + 10
					newgame.positions = newgame.positionmap("plants")
				end
			elseif action[2][2] == "*" then
				newgame.positions = newgame.positionmap("plants")
			end
		elseif action[2][1] == "size" then
			if action[2][2] == "-" then
				if game.settings.mapsize >= 2 then
					game.settings.mapsize = game.settings.mapsize - 1
					if game.settings.mapsize == 1 then
						game.settings.opponents = 0
					elseif game.settings.mapsize == 2 then
						if game.settings.opponents > 1 then
							game.settings.opponents = 1
						end
					end
					newgame.positions = newgame.positionmap()
				end
			elseif action[2][2] == "+" then
				if game.settings.mapsize <= 3 then
					game.settings.mapsize = game.settings.mapsize + 1
					newgame.positions = newgame.positionmap()
				end
			end
			
		-- return and play buttons
		elseif action[2][1] == "return" then
			game.states:setAlpha("newgame",0,200)
			newgame.destination = "return"
		elseif action[2][1] == "play" then
			game.states:setAlpha("newgame",0,200)
			newgame.destination = "play"
			game.states:setAlpha("menubackground",0,200)
			
			-- setup data for gameplay
			game.map = {}
			game.map.width = game.settings.mapsize * 800
			game.map.height = game.settings.mapsize * 600
			
			game.ai = {}
			game.ai.lodestones = {}
			game.ai.plants = {}
			game.ai.mothers = {}
			
			for i = 0,#newgame.positions-1 do
				for j = 0,#newgame.positions[i+1] do
					if newgame.positions[i+1][j+1] == "plant" then
						table.insert(game.ai.lodestones,{x=(j*800)+400,y=(i*600)+300})
					elseif type(newgame.positions[i+1][j+1]) == "number" then
						table.insert(game.ai.mothers,{x=(j*800)+400,y=(i*600)+300,id=newgame.positions[i+1][j+1]})
						if newgame.positions[i+1][j+1] == 0 then
							game.camera = {}
							game.camera.x = (j*800)+400
							game.camera.y = (i*600)+300
							game.camera.z = 1
						end
					end
				end
			end
			
		end
	end
end

newgame.init = function()
	game.states:setAlpha("newgame",255,150)
end

return newgame